==> texlive-bin_2016.20160513.41080.dfsg.orig.tar.xz: texlive-bin-2016.20160513.41080.dfsg/texk/gregorio/gregorio-src/CONTRIBUTORS.md <==
## Authors

Gregorio is developed by:

 * [Elie Roux](mailto:elie.roux@telecom-bretagne.eu)
 * [Olivier Berten](mailto:olivier.berten@gmail.com)
 * [Henry So Jr](mailto:henryso@panix.com)
 * [Br. Samuel Springuel](mailto:rpspringuel@gmail.com)
 * [Br. Elijah Schwab](mailto:elijahschwab@gmail.com)
 * [Jakub Jelínek](mailto:jakub@redhat.com)
 * [Br. Gabriel-Marie](mailto:brgabriel@sspx.com)

The following people also contributed in the past:

 * [Jérémie Corbier](mailto:jeremie.corbier@telecom-bretagne.eu)
 * [Tracy Llenos](mailto:tllenos@gmail.com)

## Thanks

Gregorio has been developed with valuable help and support from:

 * Yannis Haralambous
 * [The Abbey Ste Madeleine du Barroux (FR)](http://www.barroux.org/)
 * [The Monastery of St Benedict in Norcia (IT)](http://osbnorcia.org/)
 * Matthew Spencer (author of [Caeciliae](http://marello.org/caeciliae/))
 * Juergen Reuter (author of Parmesan font from [Lilypond](http://www.lilypond.org/index.html))
 * Nicolas Aupetit
 * Bertrand Grelot
 * Patrick Roux
 * Fr. Jacques Peron
 * Br. Innocent Smith
 * [Illuminare Publications](https://www.illuminarepublications.com/)
 * Richard Chonak
 * David Gippner
 * Quentin Lamy
 * [The Abbey of Solesmes (FR)](http://www.solesmes.com/)
 * [Abbazia di Praglia (IT)](http://www.praglia.it)
 * [Abbazia Mater Ecclesiae (IT)](http://it.wikipedia.org/wiki/Abbazia_Mater_Ecclesiae)
 * [e-codices](http://www.e-codices.unifr.ch)
 * [Stiftsbibliothek, St. Gallen (CH)](http://www.stibi.ch/)
 * [Stiftsbibliothek, Einsiedeln (CH)](http://kloster-einsiedeln.ch/)
 * [Gna!](http://gna.org)
 * [Github](https://github.com/)

## Acknowledgments

 * The SHA-1 digest code comes from [GNU coreutils](http://www.gnu.org/software/coreutils/coreutils.html) and has been adapted to suit Gregorio as permitted by the GPL, version 3 or later.  Our copyright has been added to theirs in the appropriate source files.

==> texlive-bin_2017.20170613.44572.orig.tar.xz: texlive-bin-2017.20170613.44572/texk/gregorio/gregorio-src/CONTRIBUTORS.md <==
## Authors

Gregorio is developed by:

 * [Elie Roux](mailto:elie.roux@telecom-bretagne.eu)
 * [Olivier Berten](mailto:olivier.berten@gmail.com)
 * [Henry So Jr](mailto:henryso@panix.com)
 * [Br. Samuel Springuel](mailto:rpspringuel@gmail.com)
 * [Br. Elijah Schwab](mailto:elijahschwab@gmail.com)
 * [Jakub Jelínek](mailto:jakub@redhat.com)
 * [Br. Gabriel-Marie](mailto:brgabriel@sspx.com)

The following people also contributed in the past:

 * [Jérémie Corbier](mailto:jeremie.corbier@telecom-bretagne.eu)
 * [Tracy Llenos](mailto:tllenos@gmail.com)

## Thanks

Gregorio has been developed with valuable help and support from:

 * Yannis Haralambous
 * [The Abbey Ste Madeleine du Barroux (FR)](http://www.barroux.org/)
 * [The Monastery of St Benedict in Norcia (IT)](http://osbnorcia.org/)
 * Matthew Spencer (author of [Caeciliae](http://marello.org/caeciliae/))
 * Juergen Reuter (author of Parmesan font from [Lilypond](http://www.lilypond.org/index.html))
 * Nicolas Aupetit
 * Bertrand Grelot
 * Patrick Roux
 * Fr. Jacques Peron
 * Br. Innocent Smith
 * [Illuminare Publications](https://www.illuminarepublications.com/)
 * Richard Chonak
 * David Gippner
 * Quentin Lamy
 * [The Abbey of Solesmes (FR)](http://www.solesmes.com/)
 * [The Abbey of Flavigny (FR)](http://www.clairval.com)
 * [Abbazia di Praglia (IT)](http://www.praglia.it)
 * [Abbazia Mater Ecclesiae (IT)](http://it.wikipedia.org/wiki/Abbazia_Mater_Ecclesiae)
 * [e-codices](http://www.e-codices.unifr.ch)
 * [Stiftsbibliothek, St. Gallen (CH)](http://www.stibi.ch/)
 * [Stiftsbibliothek, Einsiedeln (CH)](http://kloster-einsiedeln.ch/)
 * [Bibliothèque municipale de Laon (FR)](http://manuscrit.ville-laon.fr/)
 * [Gna!](http://gna.org)
 * [Github](https://github.com/)

## Acknowledgments

 * The SHA-1 digest code comes from [GNU coreutils](http://www.gnu.org/software/coreutils/coreutils.html) and has been adapted to suit Gregorio as permitted by the GPL, version 3 or later.  Our copyright has been added to theirs in the appropriate source files.
